# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Pixels.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Image' not in _M_omero.model.__dict__:
    _M_omero.model._t_Image = IcePy.declareClass('::omero::model::Image')
    _M_omero.model._t_ImagePrx = IcePy.declareProxy('::omero::model::Image')

if 'Pixels' not in _M_omero.model.__dict__:
    _M_omero.model._t_Pixels = IcePy.declareClass('::omero::model::Pixels')
    _M_omero.model._t_PixelsPrx = IcePy.declareProxy('::omero::model::Pixels')

if 'PixelsType' not in _M_omero.model.__dict__:
    _M_omero.model._t_PixelsType = IcePy.declareClass('::omero::model::PixelsType')
    _M_omero.model._t_PixelsTypePrx = IcePy.declareProxy('::omero::model::PixelsType')

if 'DimensionOrder' not in _M_omero.model.__dict__:
    _M_omero.model._t_DimensionOrder = IcePy.declareClass('::omero::model::DimensionOrder')
    _M_omero.model._t_DimensionOrderPrx = IcePy.declareProxy('::omero::model::DimensionOrder')

if 'Length' not in _M_omero.model.__dict__:
    _M_omero.model._t_Length = IcePy.declareClass('::omero::model::Length')
    _M_omero.model._t_LengthPrx = IcePy.declareProxy('::omero::model::Length')

if 'Time' not in _M_omero.model.__dict__:
    _M_omero.model._t_Time = IcePy.declareClass('::omero::model::Time')
    _M_omero.model._t_TimePrx = IcePy.declareProxy('::omero::model::Time')

if 'PlaneInfo' not in _M_omero.model.__dict__:
    _M_omero.model._t_PlaneInfo = IcePy.declareClass('::omero::model::PlaneInfo')
    _M_omero.model._t_PlaneInfoPrx = IcePy.declareProxy('::omero::model::PlaneInfo')

if 'PixelsOriginalFileMap' not in _M_omero.model.__dict__:
    _M_omero.model._t_PixelsOriginalFileMap = IcePy.declareClass('::omero::model::PixelsOriginalFileMap')
    _M_omero.model._t_PixelsOriginalFileMapPrx = IcePy.declareProxy('::omero::model::PixelsOriginalFileMap')

if 'OriginalFile' not in _M_omero.model.__dict__:
    _M_omero.model._t_OriginalFile = IcePy.declareClass('::omero::model::OriginalFile')
    _M_omero.model._t_OriginalFilePrx = IcePy.declareProxy('::omero::model::OriginalFile')

if 'Channel' not in _M_omero.model.__dict__:
    _M_omero.model._t_Channel = IcePy.declareClass('::omero::model::Channel')
    _M_omero.model._t_ChannelPrx = IcePy.declareProxy('::omero::model::Channel')

if 'RenderingDef' not in _M_omero.model.__dict__:
    _M_omero.model._t_RenderingDef = IcePy.declareClass('::omero::model::RenderingDef')
    _M_omero.model._t_RenderingDefPrx = IcePy.declareProxy('::omero::model::RenderingDef')

if 'Thumbnail' not in _M_omero.model.__dict__:
    _M_omero.model._t_Thumbnail = IcePy.declareClass('::omero::model::Thumbnail')
    _M_omero.model._t_ThumbnailPrx = IcePy.declareProxy('::omero::model::Thumbnail')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_PixelsPlaneInfoSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PixelsPlaneInfoSeq = IcePy.defineSequence('::omero::model::PixelsPlaneInfoSeq', (), _M_omero.model._t_PlaneInfo)

if '_t_PixelsPixelsFileMapsSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PixelsPixelsFileMapsSeq = IcePy.defineSequence('::omero::model::PixelsPixelsFileMapsSeq', (), _M_omero.model._t_PixelsOriginalFileMap)

if '_t_PixelsLinkedOriginalFileSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PixelsLinkedOriginalFileSeq = IcePy.defineSequence('::omero::model::PixelsLinkedOriginalFileSeq', (), _M_omero.model._t_OriginalFile)

if '_t_PixelsChannelsSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PixelsChannelsSeq = IcePy.defineSequence('::omero::model::PixelsChannelsSeq', (), _M_omero.model._t_Channel)

if '_t_PixelsSettingsSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PixelsSettingsSeq = IcePy.defineSequence('::omero::model::PixelsSettingsSeq', (), _M_omero.model._t_RenderingDef)

if '_t_PixelsThumbnailsSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_PixelsThumbnailsSeq = IcePy.defineSequence('::omero::model::PixelsThumbnailsSeq', (), _M_omero.model._t_Thumbnail)

if 'Pixels' not in _M_omero.model.__dict__:
    _M_omero.model.Pixels = Ice.createTempClass()
    class Pixels(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _image=None, _relatedTo=None, _pixelsType=None, _significantBits=None, _sizeX=None, _sizeY=None, _sizeZ=None, _sizeC=None, _sizeT=None, _sha1=None, _dimensionOrder=None, _physicalSizeX=None, _physicalSizeY=None, _physicalSizeZ=None, _waveStart=None, _waveIncrement=None, _timeIncrement=None, _methodology=None, _planeInfoSeq=None, _planeInfoLoaded=False, _pixelsFileMapsSeq=None, _pixelsFileMapsLoaded=False, _pixelsFileMapsCountPerOwner=None, _channelsSeq=None, _channelsLoaded=False, _settingsSeq=None, _settingsLoaded=False, _thumbnailsSeq=None, _thumbnailsLoaded=False):
            if Ice.getType(self) == _M_omero.model.Pixels:
                raise RuntimeError('omero.model.Pixels is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._image = _image
            self._relatedTo = _relatedTo
            self._pixelsType = _pixelsType
            self._significantBits = _significantBits
            self._sizeX = _sizeX
            self._sizeY = _sizeY
            self._sizeZ = _sizeZ
            self._sizeC = _sizeC
            self._sizeT = _sizeT
            self._sha1 = _sha1
            self._dimensionOrder = _dimensionOrder
            self._physicalSizeX = _physicalSizeX
            self._physicalSizeY = _physicalSizeY
            self._physicalSizeZ = _physicalSizeZ
            self._waveStart = _waveStart
            self._waveIncrement = _waveIncrement
            self._timeIncrement = _timeIncrement
            self._methodology = _methodology
            self._planeInfoSeq = _planeInfoSeq
            self._planeInfoLoaded = _planeInfoLoaded
            self._pixelsFileMapsSeq = _pixelsFileMapsSeq
            self._pixelsFileMapsLoaded = _pixelsFileMapsLoaded
            self._pixelsFileMapsCountPerOwner = _pixelsFileMapsCountPerOwner
            self._channelsSeq = _channelsSeq
            self._channelsLoaded = _channelsLoaded
            self._settingsSeq = _settingsSeq
            self._settingsLoaded = _settingsLoaded
            self._thumbnailsSeq = _thumbnailsSeq
            self._thumbnailsLoaded = _thumbnailsLoaded

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::Pixels')

        def ice_id(self, current=None):
            return '::omero::model::Pixels'

        def ice_staticId():
            return '::omero::model::Pixels'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getImage(self, current=None):
            pass

        def setImage(self, theImage, current=None):
            pass

        def getRelatedTo(self, current=None):
            pass

        def setRelatedTo(self, theRelatedTo, current=None):
            pass

        def getPixelsType(self, current=None):
            pass

        def setPixelsType(self, thePixelsType, current=None):
            pass

        def getSignificantBits(self, current=None):
            pass

        def setSignificantBits(self, theSignificantBits, current=None):
            pass

        def getSizeX(self, current=None):
            pass

        def setSizeX(self, theSizeX, current=None):
            pass

        def getSizeY(self, current=None):
            pass

        def setSizeY(self, theSizeY, current=None):
            pass

        def getSizeZ(self, current=None):
            pass

        def setSizeZ(self, theSizeZ, current=None):
            pass

        def getSizeC(self, current=None):
            pass

        def setSizeC(self, theSizeC, current=None):
            pass

        def getSizeT(self, current=None):
            pass

        def setSizeT(self, theSizeT, current=None):
            pass

        def getSha1(self, current=None):
            pass

        def setSha1(self, theSha1, current=None):
            pass

        def getDimensionOrder(self, current=None):
            pass

        def setDimensionOrder(self, theDimensionOrder, current=None):
            pass

        def getPhysicalSizeX(self, current=None):
            pass

        def setPhysicalSizeX(self, thePhysicalSizeX, current=None):
            pass

        def getPhysicalSizeY(self, current=None):
            pass

        def setPhysicalSizeY(self, thePhysicalSizeY, current=None):
            pass

        def getPhysicalSizeZ(self, current=None):
            pass

        def setPhysicalSizeZ(self, thePhysicalSizeZ, current=None):
            pass

        def getWaveStart(self, current=None):
            pass

        def setWaveStart(self, theWaveStart, current=None):
            pass

        def getWaveIncrement(self, current=None):
            pass

        def setWaveIncrement(self, theWaveIncrement, current=None):
            pass

        def getTimeIncrement(self, current=None):
            pass

        def setTimeIncrement(self, theTimeIncrement, current=None):
            pass

        def getMethodology(self, current=None):
            pass

        def setMethodology(self, theMethodology, current=None):
            pass

        def unloadPlaneInfo(self, current=None):
            pass

        def sizeOfPlaneInfo(self, current=None):
            pass

        def copyPlaneInfo(self, current=None):
            pass

        def addPlaneInfo(self, target, current=None):
            pass

        def addAllPlaneInfoSet(self, targets, current=None):
            pass

        def removePlaneInfo(self, theTarget, current=None):
            pass

        def removeAllPlaneInfoSet(self, targets, current=None):
            pass

        def clearPlaneInfo(self, current=None):
            pass

        def reloadPlaneInfo(self, toCopy, current=None):
            pass

        def unloadPixelsFileMaps(self, current=None):
            pass

        def sizeOfPixelsFileMaps(self, current=None):
            pass

        def copyPixelsFileMaps(self, current=None):
            pass

        def addPixelsOriginalFileMap(self, target, current=None):
            pass

        def addAllPixelsOriginalFileMapSet(self, targets, current=None):
            pass

        def removePixelsOriginalFileMap(self, theTarget, current=None):
            pass

        def removeAllPixelsOriginalFileMapSet(self, targets, current=None):
            pass

        def clearPixelsFileMaps(self, current=None):
            pass

        def reloadPixelsFileMaps(self, toCopy, current=None):
            pass

        def getPixelsFileMapsCountPerOwner(self, current=None):
            pass

        def linkOriginalFile(self, addition, current=None):
            pass

        def addPixelsOriginalFileMapToBoth(self, link, bothSides, current=None):
            pass

        def findPixelsOriginalFileMap(self, removal, current=None):
            pass

        def unlinkOriginalFile(self, removal, current=None):
            pass

        def removePixelsOriginalFileMapFromBoth(self, link, bothSides, current=None):
            pass

        def linkedOriginalFileList(self, current=None):
            pass

        def unloadChannels(self, current=None):
            pass

        def sizeOfChannels(self, current=None):
            pass

        def copyChannels(self, current=None):
            pass

        def addChannel(self, target, current=None):
            pass

        def addAllChannelSet(self, targets, current=None):
            pass

        def removeChannel(self, theTarget, current=None):
            pass

        def removeAllChannelSet(self, targets, current=None):
            pass

        def clearChannels(self, current=None):
            pass

        def reloadChannels(self, toCopy, current=None):
            pass

        def getChannel(self, index, current=None):
            pass

        def setChannel(self, index, theElement, current=None):
            pass

        def getPrimaryChannel(self, current=None):
            pass

        def setPrimaryChannel(self, theElement, current=None):
            pass

        def unloadSettings(self, current=None):
            pass

        def sizeOfSettings(self, current=None):
            pass

        def copySettings(self, current=None):
            pass

        def addRenderingDef(self, target, current=None):
            pass

        def addAllRenderingDefSet(self, targets, current=None):
            pass

        def removeRenderingDef(self, theTarget, current=None):
            pass

        def removeAllRenderingDefSet(self, targets, current=None):
            pass

        def clearSettings(self, current=None):
            pass

        def reloadSettings(self, toCopy, current=None):
            pass

        def unloadThumbnails(self, current=None):
            pass

        def sizeOfThumbnails(self, current=None):
            pass

        def copyThumbnails(self, current=None):
            pass

        def addThumbnail(self, target, current=None):
            pass

        def addAllThumbnailSet(self, targets, current=None):
            pass

        def removeThumbnail(self, theTarget, current=None):
            pass

        def removeAllThumbnailSet(self, targets, current=None):
            pass

        def clearThumbnails(self, current=None):
            pass

        def reloadThumbnails(self, toCopy, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Pixels)

        __repr__ = __str__

    _M_omero.model.PixelsPrx = Ice.createTempClass()
    class PixelsPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Pixels._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Pixels._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Pixels._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Pixels._op_setVersion.end(self, _r)

        def getImage(self, _ctx=None):
            return _M_omero.model.Pixels._op_getImage.invoke(self, ((), _ctx))

        def begin_getImage(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getImage.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getImage(self, _r):
            return _M_omero.model.Pixels._op_getImage.end(self, _r)

        def setImage(self, theImage, _ctx=None):
            return _M_omero.model.Pixels._op_setImage.invoke(self, ((theImage, ), _ctx))

        def begin_setImage(self, theImage, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setImage.begin(self, ((theImage, ), _response, _ex, _sent, _ctx))

        def end_setImage(self, _r):
            return _M_omero.model.Pixels._op_setImage.end(self, _r)

        def getRelatedTo(self, _ctx=None):
            return _M_omero.model.Pixels._op_getRelatedTo.invoke(self, ((), _ctx))

        def begin_getRelatedTo(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getRelatedTo.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRelatedTo(self, _r):
            return _M_omero.model.Pixels._op_getRelatedTo.end(self, _r)

        def setRelatedTo(self, theRelatedTo, _ctx=None):
            return _M_omero.model.Pixels._op_setRelatedTo.invoke(self, ((theRelatedTo, ), _ctx))

        def begin_setRelatedTo(self, theRelatedTo, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setRelatedTo.begin(self, ((theRelatedTo, ), _response, _ex, _sent, _ctx))

        def end_setRelatedTo(self, _r):
            return _M_omero.model.Pixels._op_setRelatedTo.end(self, _r)

        def getPixelsType(self, _ctx=None):
            return _M_omero.model.Pixels._op_getPixelsType.invoke(self, ((), _ctx))

        def begin_getPixelsType(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getPixelsType.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPixelsType(self, _r):
            return _M_omero.model.Pixels._op_getPixelsType.end(self, _r)

        def setPixelsType(self, thePixelsType, _ctx=None):
            return _M_omero.model.Pixels._op_setPixelsType.invoke(self, ((thePixelsType, ), _ctx))

        def begin_setPixelsType(self, thePixelsType, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setPixelsType.begin(self, ((thePixelsType, ), _response, _ex, _sent, _ctx))

        def end_setPixelsType(self, _r):
            return _M_omero.model.Pixels._op_setPixelsType.end(self, _r)

        def getSignificantBits(self, _ctx=None):
            return _M_omero.model.Pixels._op_getSignificantBits.invoke(self, ((), _ctx))

        def begin_getSignificantBits(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getSignificantBits.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSignificantBits(self, _r):
            return _M_omero.model.Pixels._op_getSignificantBits.end(self, _r)

        def setSignificantBits(self, theSignificantBits, _ctx=None):
            return _M_omero.model.Pixels._op_setSignificantBits.invoke(self, ((theSignificantBits, ), _ctx))

        def begin_setSignificantBits(self, theSignificantBits, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setSignificantBits.begin(self, ((theSignificantBits, ), _response, _ex, _sent, _ctx))

        def end_setSignificantBits(self, _r):
            return _M_omero.model.Pixels._op_setSignificantBits.end(self, _r)

        def getSizeX(self, _ctx=None):
            return _M_omero.model.Pixels._op_getSizeX.invoke(self, ((), _ctx))

        def begin_getSizeX(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getSizeX.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSizeX(self, _r):
            return _M_omero.model.Pixels._op_getSizeX.end(self, _r)

        def setSizeX(self, theSizeX, _ctx=None):
            return _M_omero.model.Pixels._op_setSizeX.invoke(self, ((theSizeX, ), _ctx))

        def begin_setSizeX(self, theSizeX, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setSizeX.begin(self, ((theSizeX, ), _response, _ex, _sent, _ctx))

        def end_setSizeX(self, _r):
            return _M_omero.model.Pixels._op_setSizeX.end(self, _r)

        def getSizeY(self, _ctx=None):
            return _M_omero.model.Pixels._op_getSizeY.invoke(self, ((), _ctx))

        def begin_getSizeY(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getSizeY.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSizeY(self, _r):
            return _M_omero.model.Pixels._op_getSizeY.end(self, _r)

        def setSizeY(self, theSizeY, _ctx=None):
            return _M_omero.model.Pixels._op_setSizeY.invoke(self, ((theSizeY, ), _ctx))

        def begin_setSizeY(self, theSizeY, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setSizeY.begin(self, ((theSizeY, ), _response, _ex, _sent, _ctx))

        def end_setSizeY(self, _r):
            return _M_omero.model.Pixels._op_setSizeY.end(self, _r)

        def getSizeZ(self, _ctx=None):
            return _M_omero.model.Pixels._op_getSizeZ.invoke(self, ((), _ctx))

        def begin_getSizeZ(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getSizeZ.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSizeZ(self, _r):
            return _M_omero.model.Pixels._op_getSizeZ.end(self, _r)

        def setSizeZ(self, theSizeZ, _ctx=None):
            return _M_omero.model.Pixels._op_setSizeZ.invoke(self, ((theSizeZ, ), _ctx))

        def begin_setSizeZ(self, theSizeZ, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setSizeZ.begin(self, ((theSizeZ, ), _response, _ex, _sent, _ctx))

        def end_setSizeZ(self, _r):
            return _M_omero.model.Pixels._op_setSizeZ.end(self, _r)

        def getSizeC(self, _ctx=None):
            return _M_omero.model.Pixels._op_getSizeC.invoke(self, ((), _ctx))

        def begin_getSizeC(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getSizeC.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSizeC(self, _r):
            return _M_omero.model.Pixels._op_getSizeC.end(self, _r)

        def setSizeC(self, theSizeC, _ctx=None):
            return _M_omero.model.Pixels._op_setSizeC.invoke(self, ((theSizeC, ), _ctx))

        def begin_setSizeC(self, theSizeC, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setSizeC.begin(self, ((theSizeC, ), _response, _ex, _sent, _ctx))

        def end_setSizeC(self, _r):
            return _M_omero.model.Pixels._op_setSizeC.end(self, _r)

        def getSizeT(self, _ctx=None):
            return _M_omero.model.Pixels._op_getSizeT.invoke(self, ((), _ctx))

        def begin_getSizeT(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getSizeT.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSizeT(self, _r):
            return _M_omero.model.Pixels._op_getSizeT.end(self, _r)

        def setSizeT(self, theSizeT, _ctx=None):
            return _M_omero.model.Pixels._op_setSizeT.invoke(self, ((theSizeT, ), _ctx))

        def begin_setSizeT(self, theSizeT, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setSizeT.begin(self, ((theSizeT, ), _response, _ex, _sent, _ctx))

        def end_setSizeT(self, _r):
            return _M_omero.model.Pixels._op_setSizeT.end(self, _r)

        def getSha1(self, _ctx=None):
            return _M_omero.model.Pixels._op_getSha1.invoke(self, ((), _ctx))

        def begin_getSha1(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getSha1.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSha1(self, _r):
            return _M_omero.model.Pixels._op_getSha1.end(self, _r)

        def setSha1(self, theSha1, _ctx=None):
            return _M_omero.model.Pixels._op_setSha1.invoke(self, ((theSha1, ), _ctx))

        def begin_setSha1(self, theSha1, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setSha1.begin(self, ((theSha1, ), _response, _ex, _sent, _ctx))

        def end_setSha1(self, _r):
            return _M_omero.model.Pixels._op_setSha1.end(self, _r)

        def getDimensionOrder(self, _ctx=None):
            return _M_omero.model.Pixels._op_getDimensionOrder.invoke(self, ((), _ctx))

        def begin_getDimensionOrder(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getDimensionOrder.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDimensionOrder(self, _r):
            return _M_omero.model.Pixels._op_getDimensionOrder.end(self, _r)

        def setDimensionOrder(self, theDimensionOrder, _ctx=None):
            return _M_omero.model.Pixels._op_setDimensionOrder.invoke(self, ((theDimensionOrder, ), _ctx))

        def begin_setDimensionOrder(self, theDimensionOrder, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setDimensionOrder.begin(self, ((theDimensionOrder, ), _response, _ex, _sent, _ctx))

        def end_setDimensionOrder(self, _r):
            return _M_omero.model.Pixels._op_setDimensionOrder.end(self, _r)

        def getPhysicalSizeX(self, _ctx=None):
            return _M_omero.model.Pixels._op_getPhysicalSizeX.invoke(self, ((), _ctx))

        def begin_getPhysicalSizeX(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getPhysicalSizeX.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPhysicalSizeX(self, _r):
            return _M_omero.model.Pixels._op_getPhysicalSizeX.end(self, _r)

        def setPhysicalSizeX(self, thePhysicalSizeX, _ctx=None):
            return _M_omero.model.Pixels._op_setPhysicalSizeX.invoke(self, ((thePhysicalSizeX, ), _ctx))

        def begin_setPhysicalSizeX(self, thePhysicalSizeX, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setPhysicalSizeX.begin(self, ((thePhysicalSizeX, ), _response, _ex, _sent, _ctx))

        def end_setPhysicalSizeX(self, _r):
            return _M_omero.model.Pixels._op_setPhysicalSizeX.end(self, _r)

        def getPhysicalSizeY(self, _ctx=None):
            return _M_omero.model.Pixels._op_getPhysicalSizeY.invoke(self, ((), _ctx))

        def begin_getPhysicalSizeY(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getPhysicalSizeY.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPhysicalSizeY(self, _r):
            return _M_omero.model.Pixels._op_getPhysicalSizeY.end(self, _r)

        def setPhysicalSizeY(self, thePhysicalSizeY, _ctx=None):
            return _M_omero.model.Pixels._op_setPhysicalSizeY.invoke(self, ((thePhysicalSizeY, ), _ctx))

        def begin_setPhysicalSizeY(self, thePhysicalSizeY, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setPhysicalSizeY.begin(self, ((thePhysicalSizeY, ), _response, _ex, _sent, _ctx))

        def end_setPhysicalSizeY(self, _r):
            return _M_omero.model.Pixels._op_setPhysicalSizeY.end(self, _r)

        def getPhysicalSizeZ(self, _ctx=None):
            return _M_omero.model.Pixels._op_getPhysicalSizeZ.invoke(self, ((), _ctx))

        def begin_getPhysicalSizeZ(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getPhysicalSizeZ.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPhysicalSizeZ(self, _r):
            return _M_omero.model.Pixels._op_getPhysicalSizeZ.end(self, _r)

        def setPhysicalSizeZ(self, thePhysicalSizeZ, _ctx=None):
            return _M_omero.model.Pixels._op_setPhysicalSizeZ.invoke(self, ((thePhysicalSizeZ, ), _ctx))

        def begin_setPhysicalSizeZ(self, thePhysicalSizeZ, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setPhysicalSizeZ.begin(self, ((thePhysicalSizeZ, ), _response, _ex, _sent, _ctx))

        def end_setPhysicalSizeZ(self, _r):
            return _M_omero.model.Pixels._op_setPhysicalSizeZ.end(self, _r)

        def getWaveStart(self, _ctx=None):
            return _M_omero.model.Pixels._op_getWaveStart.invoke(self, ((), _ctx))

        def begin_getWaveStart(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getWaveStart.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getWaveStart(self, _r):
            return _M_omero.model.Pixels._op_getWaveStart.end(self, _r)

        def setWaveStart(self, theWaveStart, _ctx=None):
            return _M_omero.model.Pixels._op_setWaveStart.invoke(self, ((theWaveStart, ), _ctx))

        def begin_setWaveStart(self, theWaveStart, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setWaveStart.begin(self, ((theWaveStart, ), _response, _ex, _sent, _ctx))

        def end_setWaveStart(self, _r):
            return _M_omero.model.Pixels._op_setWaveStart.end(self, _r)

        def getWaveIncrement(self, _ctx=None):
            return _M_omero.model.Pixels._op_getWaveIncrement.invoke(self, ((), _ctx))

        def begin_getWaveIncrement(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getWaveIncrement.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getWaveIncrement(self, _r):
            return _M_omero.model.Pixels._op_getWaveIncrement.end(self, _r)

        def setWaveIncrement(self, theWaveIncrement, _ctx=None):
            return _M_omero.model.Pixels._op_setWaveIncrement.invoke(self, ((theWaveIncrement, ), _ctx))

        def begin_setWaveIncrement(self, theWaveIncrement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setWaveIncrement.begin(self, ((theWaveIncrement, ), _response, _ex, _sent, _ctx))

        def end_setWaveIncrement(self, _r):
            return _M_omero.model.Pixels._op_setWaveIncrement.end(self, _r)

        def getTimeIncrement(self, _ctx=None):
            return _M_omero.model.Pixels._op_getTimeIncrement.invoke(self, ((), _ctx))

        def begin_getTimeIncrement(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getTimeIncrement.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTimeIncrement(self, _r):
            return _M_omero.model.Pixels._op_getTimeIncrement.end(self, _r)

        def setTimeIncrement(self, theTimeIncrement, _ctx=None):
            return _M_omero.model.Pixels._op_setTimeIncrement.invoke(self, ((theTimeIncrement, ), _ctx))

        def begin_setTimeIncrement(self, theTimeIncrement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setTimeIncrement.begin(self, ((theTimeIncrement, ), _response, _ex, _sent, _ctx))

        def end_setTimeIncrement(self, _r):
            return _M_omero.model.Pixels._op_setTimeIncrement.end(self, _r)

        def getMethodology(self, _ctx=None):
            return _M_omero.model.Pixels._op_getMethodology.invoke(self, ((), _ctx))

        def begin_getMethodology(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getMethodology.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMethodology(self, _r):
            return _M_omero.model.Pixels._op_getMethodology.end(self, _r)

        def setMethodology(self, theMethodology, _ctx=None):
            return _M_omero.model.Pixels._op_setMethodology.invoke(self, ((theMethodology, ), _ctx))

        def begin_setMethodology(self, theMethodology, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setMethodology.begin(self, ((theMethodology, ), _response, _ex, _sent, _ctx))

        def end_setMethodology(self, _r):
            return _M_omero.model.Pixels._op_setMethodology.end(self, _r)

        def unloadPlaneInfo(self, _ctx=None):
            return _M_omero.model.Pixels._op_unloadPlaneInfo.invoke(self, ((), _ctx))

        def begin_unloadPlaneInfo(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_unloadPlaneInfo.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadPlaneInfo(self, _r):
            return _M_omero.model.Pixels._op_unloadPlaneInfo.end(self, _r)

        def sizeOfPlaneInfo(self, _ctx=None):
            return _M_omero.model.Pixels._op_sizeOfPlaneInfo.invoke(self, ((), _ctx))

        def begin_sizeOfPlaneInfo(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_sizeOfPlaneInfo.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfPlaneInfo(self, _r):
            return _M_omero.model.Pixels._op_sizeOfPlaneInfo.end(self, _r)

        def copyPlaneInfo(self, _ctx=None):
            return _M_omero.model.Pixels._op_copyPlaneInfo.invoke(self, ((), _ctx))

        def begin_copyPlaneInfo(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_copyPlaneInfo.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyPlaneInfo(self, _r):
            return _M_omero.model.Pixels._op_copyPlaneInfo.end(self, _r)

        def addPlaneInfo(self, target, _ctx=None):
            return _M_omero.model.Pixels._op_addPlaneInfo.invoke(self, ((target, ), _ctx))

        def begin_addPlaneInfo(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_addPlaneInfo.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addPlaneInfo(self, _r):
            return _M_omero.model.Pixels._op_addPlaneInfo.end(self, _r)

        def addAllPlaneInfoSet(self, targets, _ctx=None):
            return _M_omero.model.Pixels._op_addAllPlaneInfoSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllPlaneInfoSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_addAllPlaneInfoSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllPlaneInfoSet(self, _r):
            return _M_omero.model.Pixels._op_addAllPlaneInfoSet.end(self, _r)

        def removePlaneInfo(self, theTarget, _ctx=None):
            return _M_omero.model.Pixels._op_removePlaneInfo.invoke(self, ((theTarget, ), _ctx))

        def begin_removePlaneInfo(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_removePlaneInfo.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removePlaneInfo(self, _r):
            return _M_omero.model.Pixels._op_removePlaneInfo.end(self, _r)

        def removeAllPlaneInfoSet(self, targets, _ctx=None):
            return _M_omero.model.Pixels._op_removeAllPlaneInfoSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllPlaneInfoSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_removeAllPlaneInfoSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllPlaneInfoSet(self, _r):
            return _M_omero.model.Pixels._op_removeAllPlaneInfoSet.end(self, _r)

        def clearPlaneInfo(self, _ctx=None):
            return _M_omero.model.Pixels._op_clearPlaneInfo.invoke(self, ((), _ctx))

        def begin_clearPlaneInfo(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_clearPlaneInfo.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearPlaneInfo(self, _r):
            return _M_omero.model.Pixels._op_clearPlaneInfo.end(self, _r)

        def reloadPlaneInfo(self, toCopy, _ctx=None):
            return _M_omero.model.Pixels._op_reloadPlaneInfo.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadPlaneInfo(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_reloadPlaneInfo.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadPlaneInfo(self, _r):
            return _M_omero.model.Pixels._op_reloadPlaneInfo.end(self, _r)

        def unloadPixelsFileMaps(self, _ctx=None):
            return _M_omero.model.Pixels._op_unloadPixelsFileMaps.invoke(self, ((), _ctx))

        def begin_unloadPixelsFileMaps(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_unloadPixelsFileMaps.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadPixelsFileMaps(self, _r):
            return _M_omero.model.Pixels._op_unloadPixelsFileMaps.end(self, _r)

        def sizeOfPixelsFileMaps(self, _ctx=None):
            return _M_omero.model.Pixels._op_sizeOfPixelsFileMaps.invoke(self, ((), _ctx))

        def begin_sizeOfPixelsFileMaps(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_sizeOfPixelsFileMaps.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfPixelsFileMaps(self, _r):
            return _M_omero.model.Pixels._op_sizeOfPixelsFileMaps.end(self, _r)

        def copyPixelsFileMaps(self, _ctx=None):
            return _M_omero.model.Pixels._op_copyPixelsFileMaps.invoke(self, ((), _ctx))

        def begin_copyPixelsFileMaps(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_copyPixelsFileMaps.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyPixelsFileMaps(self, _r):
            return _M_omero.model.Pixels._op_copyPixelsFileMaps.end(self, _r)

        def addPixelsOriginalFileMap(self, target, _ctx=None):
            return _M_omero.model.Pixels._op_addPixelsOriginalFileMap.invoke(self, ((target, ), _ctx))

        def begin_addPixelsOriginalFileMap(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_addPixelsOriginalFileMap.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addPixelsOriginalFileMap(self, _r):
            return _M_omero.model.Pixels._op_addPixelsOriginalFileMap.end(self, _r)

        def addAllPixelsOriginalFileMapSet(self, targets, _ctx=None):
            return _M_omero.model.Pixels._op_addAllPixelsOriginalFileMapSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllPixelsOriginalFileMapSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_addAllPixelsOriginalFileMapSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllPixelsOriginalFileMapSet(self, _r):
            return _M_omero.model.Pixels._op_addAllPixelsOriginalFileMapSet.end(self, _r)

        def removePixelsOriginalFileMap(self, theTarget, _ctx=None):
            return _M_omero.model.Pixels._op_removePixelsOriginalFileMap.invoke(self, ((theTarget, ), _ctx))

        def begin_removePixelsOriginalFileMap(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_removePixelsOriginalFileMap.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removePixelsOriginalFileMap(self, _r):
            return _M_omero.model.Pixels._op_removePixelsOriginalFileMap.end(self, _r)

        def removeAllPixelsOriginalFileMapSet(self, targets, _ctx=None):
            return _M_omero.model.Pixels._op_removeAllPixelsOriginalFileMapSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllPixelsOriginalFileMapSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_removeAllPixelsOriginalFileMapSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllPixelsOriginalFileMapSet(self, _r):
            return _M_omero.model.Pixels._op_removeAllPixelsOriginalFileMapSet.end(self, _r)

        def clearPixelsFileMaps(self, _ctx=None):
            return _M_omero.model.Pixels._op_clearPixelsFileMaps.invoke(self, ((), _ctx))

        def begin_clearPixelsFileMaps(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_clearPixelsFileMaps.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearPixelsFileMaps(self, _r):
            return _M_omero.model.Pixels._op_clearPixelsFileMaps.end(self, _r)

        def reloadPixelsFileMaps(self, toCopy, _ctx=None):
            return _M_omero.model.Pixels._op_reloadPixelsFileMaps.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadPixelsFileMaps(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_reloadPixelsFileMaps.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadPixelsFileMaps(self, _r):
            return _M_omero.model.Pixels._op_reloadPixelsFileMaps.end(self, _r)

        def getPixelsFileMapsCountPerOwner(self, _ctx=None):
            return _M_omero.model.Pixels._op_getPixelsFileMapsCountPerOwner.invoke(self, ((), _ctx))

        def begin_getPixelsFileMapsCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getPixelsFileMapsCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPixelsFileMapsCountPerOwner(self, _r):
            return _M_omero.model.Pixels._op_getPixelsFileMapsCountPerOwner.end(self, _r)

        def linkOriginalFile(self, addition, _ctx=None):
            return _M_omero.model.Pixels._op_linkOriginalFile.invoke(self, ((addition, ), _ctx))

        def begin_linkOriginalFile(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_linkOriginalFile.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkOriginalFile(self, _r):
            return _M_omero.model.Pixels._op_linkOriginalFile.end(self, _r)

        def addPixelsOriginalFileMapToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Pixels._op_addPixelsOriginalFileMapToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addPixelsOriginalFileMapToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_addPixelsOriginalFileMapToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addPixelsOriginalFileMapToBoth(self, _r):
            return _M_omero.model.Pixels._op_addPixelsOriginalFileMapToBoth.end(self, _r)

        def findPixelsOriginalFileMap(self, removal, _ctx=None):
            return _M_omero.model.Pixels._op_findPixelsOriginalFileMap.invoke(self, ((removal, ), _ctx))

        def begin_findPixelsOriginalFileMap(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_findPixelsOriginalFileMap.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findPixelsOriginalFileMap(self, _r):
            return _M_omero.model.Pixels._op_findPixelsOriginalFileMap.end(self, _r)

        def unlinkOriginalFile(self, removal, _ctx=None):
            return _M_omero.model.Pixels._op_unlinkOriginalFile.invoke(self, ((removal, ), _ctx))

        def begin_unlinkOriginalFile(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_unlinkOriginalFile.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkOriginalFile(self, _r):
            return _M_omero.model.Pixels._op_unlinkOriginalFile.end(self, _r)

        def removePixelsOriginalFileMapFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Pixels._op_removePixelsOriginalFileMapFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removePixelsOriginalFileMapFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_removePixelsOriginalFileMapFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removePixelsOriginalFileMapFromBoth(self, _r):
            return _M_omero.model.Pixels._op_removePixelsOriginalFileMapFromBoth.end(self, _r)

        def linkedOriginalFileList(self, _ctx=None):
            return _M_omero.model.Pixels._op_linkedOriginalFileList.invoke(self, ((), _ctx))

        def begin_linkedOriginalFileList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_linkedOriginalFileList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedOriginalFileList(self, _r):
            return _M_omero.model.Pixels._op_linkedOriginalFileList.end(self, _r)

        def unloadChannels(self, _ctx=None):
            return _M_omero.model.Pixels._op_unloadChannels.invoke(self, ((), _ctx))

        def begin_unloadChannels(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_unloadChannels.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadChannels(self, _r):
            return _M_omero.model.Pixels._op_unloadChannels.end(self, _r)

        def sizeOfChannels(self, _ctx=None):
            return _M_omero.model.Pixels._op_sizeOfChannels.invoke(self, ((), _ctx))

        def begin_sizeOfChannels(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_sizeOfChannels.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfChannels(self, _r):
            return _M_omero.model.Pixels._op_sizeOfChannels.end(self, _r)

        def copyChannels(self, _ctx=None):
            return _M_omero.model.Pixels._op_copyChannels.invoke(self, ((), _ctx))

        def begin_copyChannels(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_copyChannels.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyChannels(self, _r):
            return _M_omero.model.Pixels._op_copyChannels.end(self, _r)

        def addChannel(self, target, _ctx=None):
            return _M_omero.model.Pixels._op_addChannel.invoke(self, ((target, ), _ctx))

        def begin_addChannel(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_addChannel.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addChannel(self, _r):
            return _M_omero.model.Pixels._op_addChannel.end(self, _r)

        def addAllChannelSet(self, targets, _ctx=None):
            return _M_omero.model.Pixels._op_addAllChannelSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllChannelSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_addAllChannelSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllChannelSet(self, _r):
            return _M_omero.model.Pixels._op_addAllChannelSet.end(self, _r)

        def removeChannel(self, theTarget, _ctx=None):
            return _M_omero.model.Pixels._op_removeChannel.invoke(self, ((theTarget, ), _ctx))

        def begin_removeChannel(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_removeChannel.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeChannel(self, _r):
            return _M_omero.model.Pixels._op_removeChannel.end(self, _r)

        def removeAllChannelSet(self, targets, _ctx=None):
            return _M_omero.model.Pixels._op_removeAllChannelSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllChannelSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_removeAllChannelSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllChannelSet(self, _r):
            return _M_omero.model.Pixels._op_removeAllChannelSet.end(self, _r)

        def clearChannels(self, _ctx=None):
            return _M_omero.model.Pixels._op_clearChannels.invoke(self, ((), _ctx))

        def begin_clearChannels(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_clearChannels.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearChannels(self, _r):
            return _M_omero.model.Pixels._op_clearChannels.end(self, _r)

        def reloadChannels(self, toCopy, _ctx=None):
            return _M_omero.model.Pixels._op_reloadChannels.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadChannels(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_reloadChannels.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadChannels(self, _r):
            return _M_omero.model.Pixels._op_reloadChannels.end(self, _r)

        def getChannel(self, index, _ctx=None):
            return _M_omero.model.Pixels._op_getChannel.invoke(self, ((index, ), _ctx))

        def begin_getChannel(self, index, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getChannel.begin(self, ((index, ), _response, _ex, _sent, _ctx))

        def end_getChannel(self, _r):
            return _M_omero.model.Pixels._op_getChannel.end(self, _r)

        def setChannel(self, index, theElement, _ctx=None):
            return _M_omero.model.Pixels._op_setChannel.invoke(self, ((index, theElement), _ctx))

        def begin_setChannel(self, index, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setChannel.begin(self, ((index, theElement), _response, _ex, _sent, _ctx))

        def end_setChannel(self, _r):
            return _M_omero.model.Pixels._op_setChannel.end(self, _r)

        def getPrimaryChannel(self, _ctx=None):
            return _M_omero.model.Pixels._op_getPrimaryChannel.invoke(self, ((), _ctx))

        def begin_getPrimaryChannel(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_getPrimaryChannel.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPrimaryChannel(self, _r):
            return _M_omero.model.Pixels._op_getPrimaryChannel.end(self, _r)

        def setPrimaryChannel(self, theElement, _ctx=None):
            return _M_omero.model.Pixels._op_setPrimaryChannel.invoke(self, ((theElement, ), _ctx))

        def begin_setPrimaryChannel(self, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_setPrimaryChannel.begin(self, ((theElement, ), _response, _ex, _sent, _ctx))

        def end_setPrimaryChannel(self, _r):
            return _M_omero.model.Pixels._op_setPrimaryChannel.end(self, _r)

        def unloadSettings(self, _ctx=None):
            return _M_omero.model.Pixels._op_unloadSettings.invoke(self, ((), _ctx))

        def begin_unloadSettings(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_unloadSettings.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadSettings(self, _r):
            return _M_omero.model.Pixels._op_unloadSettings.end(self, _r)

        def sizeOfSettings(self, _ctx=None):
            return _M_omero.model.Pixels._op_sizeOfSettings.invoke(self, ((), _ctx))

        def begin_sizeOfSettings(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_sizeOfSettings.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfSettings(self, _r):
            return _M_omero.model.Pixels._op_sizeOfSettings.end(self, _r)

        def copySettings(self, _ctx=None):
            return _M_omero.model.Pixels._op_copySettings.invoke(self, ((), _ctx))

        def begin_copySettings(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_copySettings.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copySettings(self, _r):
            return _M_omero.model.Pixels._op_copySettings.end(self, _r)

        def addRenderingDef(self, target, _ctx=None):
            return _M_omero.model.Pixels._op_addRenderingDef.invoke(self, ((target, ), _ctx))

        def begin_addRenderingDef(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_addRenderingDef.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addRenderingDef(self, _r):
            return _M_omero.model.Pixels._op_addRenderingDef.end(self, _r)

        def addAllRenderingDefSet(self, targets, _ctx=None):
            return _M_omero.model.Pixels._op_addAllRenderingDefSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllRenderingDefSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_addAllRenderingDefSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllRenderingDefSet(self, _r):
            return _M_omero.model.Pixels._op_addAllRenderingDefSet.end(self, _r)

        def removeRenderingDef(self, theTarget, _ctx=None):
            return _M_omero.model.Pixels._op_removeRenderingDef.invoke(self, ((theTarget, ), _ctx))

        def begin_removeRenderingDef(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_removeRenderingDef.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeRenderingDef(self, _r):
            return _M_omero.model.Pixels._op_removeRenderingDef.end(self, _r)

        def removeAllRenderingDefSet(self, targets, _ctx=None):
            return _M_omero.model.Pixels._op_removeAllRenderingDefSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllRenderingDefSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_removeAllRenderingDefSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllRenderingDefSet(self, _r):
            return _M_omero.model.Pixels._op_removeAllRenderingDefSet.end(self, _r)

        def clearSettings(self, _ctx=None):
            return _M_omero.model.Pixels._op_clearSettings.invoke(self, ((), _ctx))

        def begin_clearSettings(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_clearSettings.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearSettings(self, _r):
            return _M_omero.model.Pixels._op_clearSettings.end(self, _r)

        def reloadSettings(self, toCopy, _ctx=None):
            return _M_omero.model.Pixels._op_reloadSettings.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadSettings(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_reloadSettings.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadSettings(self, _r):
            return _M_omero.model.Pixels._op_reloadSettings.end(self, _r)

        def unloadThumbnails(self, _ctx=None):
            return _M_omero.model.Pixels._op_unloadThumbnails.invoke(self, ((), _ctx))

        def begin_unloadThumbnails(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_unloadThumbnails.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadThumbnails(self, _r):
            return _M_omero.model.Pixels._op_unloadThumbnails.end(self, _r)

        def sizeOfThumbnails(self, _ctx=None):
            return _M_omero.model.Pixels._op_sizeOfThumbnails.invoke(self, ((), _ctx))

        def begin_sizeOfThumbnails(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_sizeOfThumbnails.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfThumbnails(self, _r):
            return _M_omero.model.Pixels._op_sizeOfThumbnails.end(self, _r)

        def copyThumbnails(self, _ctx=None):
            return _M_omero.model.Pixels._op_copyThumbnails.invoke(self, ((), _ctx))

        def begin_copyThumbnails(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_copyThumbnails.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyThumbnails(self, _r):
            return _M_omero.model.Pixels._op_copyThumbnails.end(self, _r)

        def addThumbnail(self, target, _ctx=None):
            return _M_omero.model.Pixels._op_addThumbnail.invoke(self, ((target, ), _ctx))

        def begin_addThumbnail(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_addThumbnail.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addThumbnail(self, _r):
            return _M_omero.model.Pixels._op_addThumbnail.end(self, _r)

        def addAllThumbnailSet(self, targets, _ctx=None):
            return _M_omero.model.Pixels._op_addAllThumbnailSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllThumbnailSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_addAllThumbnailSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllThumbnailSet(self, _r):
            return _M_omero.model.Pixels._op_addAllThumbnailSet.end(self, _r)

        def removeThumbnail(self, theTarget, _ctx=None):
            return _M_omero.model.Pixels._op_removeThumbnail.invoke(self, ((theTarget, ), _ctx))

        def begin_removeThumbnail(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_removeThumbnail.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeThumbnail(self, _r):
            return _M_omero.model.Pixels._op_removeThumbnail.end(self, _r)

        def removeAllThumbnailSet(self, targets, _ctx=None):
            return _M_omero.model.Pixels._op_removeAllThumbnailSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllThumbnailSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_removeAllThumbnailSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllThumbnailSet(self, _r):
            return _M_omero.model.Pixels._op_removeAllThumbnailSet.end(self, _r)

        def clearThumbnails(self, _ctx=None):
            return _M_omero.model.Pixels._op_clearThumbnails.invoke(self, ((), _ctx))

        def begin_clearThumbnails(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_clearThumbnails.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearThumbnails(self, _r):
            return _M_omero.model.Pixels._op_clearThumbnails.end(self, _r)

        def reloadThumbnails(self, toCopy, _ctx=None):
            return _M_omero.model.Pixels._op_reloadThumbnails.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadThumbnails(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Pixels._op_reloadThumbnails.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadThumbnails(self, _r):
            return _M_omero.model.Pixels._op_reloadThumbnails.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.PixelsPrx.ice_checkedCast(proxy, '::omero::model::Pixels', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.PixelsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Pixels'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_PixelsPrx = IcePy.defineProxy('::omero::model::Pixels', PixelsPrx)

    _M_omero.model._t_Pixels = IcePy.defineClass('::omero::model::Pixels', Pixels, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_image', (), _M_omero.model._t_Image, False, 0),
        ('_relatedTo', (), _M_omero.model._t_Pixels, False, 0),
        ('_pixelsType', (), _M_omero.model._t_PixelsType, False, 0),
        ('_significantBits', (), _M_omero._t_RInt, False, 0),
        ('_sizeX', (), _M_omero._t_RInt, False, 0),
        ('_sizeY', (), _M_omero._t_RInt, False, 0),
        ('_sizeZ', (), _M_omero._t_RInt, False, 0),
        ('_sizeC', (), _M_omero._t_RInt, False, 0),
        ('_sizeT', (), _M_omero._t_RInt, False, 0),
        ('_sha1', (), _M_omero._t_RString, False, 0),
        ('_dimensionOrder', (), _M_omero.model._t_DimensionOrder, False, 0),
        ('_physicalSizeX', (), _M_omero.model._t_Length, False, 0),
        ('_physicalSizeY', (), _M_omero.model._t_Length, False, 0),
        ('_physicalSizeZ', (), _M_omero.model._t_Length, False, 0),
        ('_waveStart', (), _M_omero._t_RInt, False, 0),
        ('_waveIncrement', (), _M_omero._t_RInt, False, 0),
        ('_timeIncrement', (), _M_omero.model._t_Time, False, 0),
        ('_methodology', (), _M_omero._t_RString, False, 0),
        ('_planeInfoSeq', (), _M_omero.model._t_PixelsPlaneInfoSeq, False, 0),
        ('_planeInfoLoaded', (), IcePy._t_bool, False, 0),
        ('_pixelsFileMapsSeq', (), _M_omero.model._t_PixelsPixelsFileMapsSeq, False, 0),
        ('_pixelsFileMapsLoaded', (), IcePy._t_bool, False, 0),
        ('_pixelsFileMapsCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_channelsSeq', (), _M_omero.model._t_PixelsChannelsSeq, False, 0),
        ('_channelsLoaded', (), IcePy._t_bool, False, 0),
        ('_settingsSeq', (), _M_omero.model._t_PixelsSettingsSeq, False, 0),
        ('_settingsLoaded', (), IcePy._t_bool, False, 0),
        ('_thumbnailsSeq', (), _M_omero.model._t_PixelsThumbnailsSeq, False, 0),
        ('_thumbnailsLoaded', (), IcePy._t_bool, False, 0)
    ))
    Pixels._ice_type = _M_omero.model._t_Pixels

    Pixels._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Pixels._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Pixels._op_getImage = IcePy.Operation('getImage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Image, False, 0), ())
    Pixels._op_setImage = IcePy.Operation('setImage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Image, False, 0),), (), None, ())
    Pixels._op_getRelatedTo = IcePy.Operation('getRelatedTo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Pixels, False, 0), ())
    Pixels._op_getRelatedTo.deprecate("relatedTo is deprecated.")
    Pixels._op_setRelatedTo = IcePy.Operation('setRelatedTo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Pixels, False, 0),), (), None, ())
    Pixels._op_setRelatedTo.deprecate("relatedTo is deprecated.")
    Pixels._op_getPixelsType = IcePy.Operation('getPixelsType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PixelsType, False, 0), ())
    Pixels._op_setPixelsType = IcePy.Operation('setPixelsType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsType, False, 0),), (), None, ())
    Pixels._op_getSignificantBits = IcePy.Operation('getSignificantBits', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Pixels._op_setSignificantBits = IcePy.Operation('setSignificantBits', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Pixels._op_getSizeX = IcePy.Operation('getSizeX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Pixels._op_setSizeX = IcePy.Operation('setSizeX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Pixels._op_getSizeY = IcePy.Operation('getSizeY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Pixels._op_setSizeY = IcePy.Operation('setSizeY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Pixels._op_getSizeZ = IcePy.Operation('getSizeZ', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Pixels._op_setSizeZ = IcePy.Operation('setSizeZ', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Pixels._op_getSizeC = IcePy.Operation('getSizeC', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Pixels._op_setSizeC = IcePy.Operation('setSizeC', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Pixels._op_getSizeT = IcePy.Operation('getSizeT', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Pixels._op_setSizeT = IcePy.Operation('setSizeT', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Pixels._op_getSha1 = IcePy.Operation('getSha1', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Pixels._op_setSha1 = IcePy.Operation('setSha1', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Pixels._op_getDimensionOrder = IcePy.Operation('getDimensionOrder', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_DimensionOrder, False, 0), ())
    Pixels._op_setDimensionOrder = IcePy.Operation('setDimensionOrder', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_DimensionOrder, False, 0),), (), None, ())
    Pixels._op_getPhysicalSizeX = IcePy.Operation('getPhysicalSizeX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    Pixels._op_setPhysicalSizeX = IcePy.Operation('setPhysicalSizeX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    Pixels._op_getPhysicalSizeY = IcePy.Operation('getPhysicalSizeY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    Pixels._op_setPhysicalSizeY = IcePy.Operation('setPhysicalSizeY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    Pixels._op_getPhysicalSizeZ = IcePy.Operation('getPhysicalSizeZ', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    Pixels._op_setPhysicalSizeZ = IcePy.Operation('setPhysicalSizeZ', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    Pixels._op_getWaveStart = IcePy.Operation('getWaveStart', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Pixels._op_setWaveStart = IcePy.Operation('setWaveStart', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Pixels._op_getWaveIncrement = IcePy.Operation('getWaveIncrement', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Pixels._op_setWaveIncrement = IcePy.Operation('setWaveIncrement', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Pixels._op_getTimeIncrement = IcePy.Operation('getTimeIncrement', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Time, False, 0), ())
    Pixels._op_setTimeIncrement = IcePy.Operation('setTimeIncrement', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Time, False, 0),), (), None, ())
    Pixels._op_getMethodology = IcePy.Operation('getMethodology', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Pixels._op_setMethodology = IcePy.Operation('setMethodology', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Pixels._op_unloadPlaneInfo = IcePy.Operation('unloadPlaneInfo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Pixels._op_sizeOfPlaneInfo = IcePy.Operation('sizeOfPlaneInfo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Pixels._op_copyPlaneInfo = IcePy.Operation('copyPlaneInfo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PixelsPlaneInfoSeq, False, 0), ())
    Pixels._op_addPlaneInfo = IcePy.Operation('addPlaneInfo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlaneInfo, False, 0),), (), None, ())
    Pixels._op_addAllPlaneInfoSet = IcePy.Operation('addAllPlaneInfoSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsPlaneInfoSeq, False, 0),), (), None, ())
    Pixels._op_removePlaneInfo = IcePy.Operation('removePlaneInfo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PlaneInfo, False, 0),), (), None, ())
    Pixels._op_removeAllPlaneInfoSet = IcePy.Operation('removeAllPlaneInfoSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsPlaneInfoSeq, False, 0),), (), None, ())
    Pixels._op_clearPlaneInfo = IcePy.Operation('clearPlaneInfo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Pixels._op_reloadPlaneInfo = IcePy.Operation('reloadPlaneInfo', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Pixels, False, 0),), (), None, ())
    Pixels._op_unloadPixelsFileMaps = IcePy.Operation('unloadPixelsFileMaps', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Pixels._op_sizeOfPixelsFileMaps = IcePy.Operation('sizeOfPixelsFileMaps', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Pixels._op_copyPixelsFileMaps = IcePy.Operation('copyPixelsFileMaps', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PixelsPixelsFileMapsSeq, False, 0), ())
    Pixels._op_addPixelsOriginalFileMap = IcePy.Operation('addPixelsOriginalFileMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsOriginalFileMap, False, 0),), (), None, ())
    Pixels._op_addAllPixelsOriginalFileMapSet = IcePy.Operation('addAllPixelsOriginalFileMapSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsPixelsFileMapsSeq, False, 0),), (), None, ())
    Pixels._op_removePixelsOriginalFileMap = IcePy.Operation('removePixelsOriginalFileMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsOriginalFileMap, False, 0),), (), None, ())
    Pixels._op_removeAllPixelsOriginalFileMapSet = IcePy.Operation('removeAllPixelsOriginalFileMapSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsPixelsFileMapsSeq, False, 0),), (), None, ())
    Pixels._op_clearPixelsFileMaps = IcePy.Operation('clearPixelsFileMaps', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Pixels._op_reloadPixelsFileMaps = IcePy.Operation('reloadPixelsFileMaps', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Pixels, False, 0),), (), None, ())
    Pixels._op_getPixelsFileMapsCountPerOwner = IcePy.Operation('getPixelsFileMapsCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Pixels._op_linkOriginalFile = IcePy.Operation('linkOriginalFile', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFile, False, 0),), (), ((), _M_omero.model._t_PixelsOriginalFileMap, False, 0), ())
    Pixels._op_addPixelsOriginalFileMapToBoth = IcePy.Operation('addPixelsOriginalFileMapToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsOriginalFileMap, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Pixels._op_findPixelsOriginalFileMap = IcePy.Operation('findPixelsOriginalFileMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFile, False, 0),), (), ((), _M_omero.model._t_PixelsPixelsFileMapsSeq, False, 0), ())
    Pixels._op_unlinkOriginalFile = IcePy.Operation('unlinkOriginalFile', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFile, False, 0),), (), None, ())
    Pixels._op_removePixelsOriginalFileMapFromBoth = IcePy.Operation('removePixelsOriginalFileMapFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsOriginalFileMap, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Pixels._op_linkedOriginalFileList = IcePy.Operation('linkedOriginalFileList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PixelsLinkedOriginalFileSeq, False, 0), ())
    Pixels._op_unloadChannels = IcePy.Operation('unloadChannels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Pixels._op_sizeOfChannels = IcePy.Operation('sizeOfChannels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Pixels._op_copyChannels = IcePy.Operation('copyChannels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PixelsChannelsSeq, False, 0), ())
    Pixels._op_addChannel = IcePy.Operation('addChannel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Channel, False, 0),), (), None, ())
    Pixels._op_addAllChannelSet = IcePy.Operation('addAllChannelSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsChannelsSeq, False, 0),), (), None, ())
    Pixels._op_removeChannel = IcePy.Operation('removeChannel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Channel, False, 0),), (), None, ())
    Pixels._op_removeAllChannelSet = IcePy.Operation('removeAllChannelSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsChannelsSeq, False, 0),), (), None, ())
    Pixels._op_clearChannels = IcePy.Operation('clearChannels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Pixels._op_reloadChannels = IcePy.Operation('reloadChannels', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Pixels, False, 0),), (), None, ())
    Pixels._op_getChannel = IcePy.Operation('getChannel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0),), (), ((), _M_omero.model._t_Channel, False, 0), ())
    Pixels._op_setChannel = IcePy.Operation('setChannel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0), ((), _M_omero.model._t_Channel, False, 0)), (), ((), _M_omero.model._t_Channel, False, 0), ())
    Pixels._op_getPrimaryChannel = IcePy.Operation('getPrimaryChannel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Channel, False, 0), ())
    Pixels._op_setPrimaryChannel = IcePy.Operation('setPrimaryChannel', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Channel, False, 0),), (), ((), _M_omero.model._t_Channel, False, 0), ())
    Pixels._op_unloadSettings = IcePy.Operation('unloadSettings', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Pixels._op_sizeOfSettings = IcePy.Operation('sizeOfSettings', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Pixels._op_copySettings = IcePy.Operation('copySettings', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PixelsSettingsSeq, False, 0), ())
    Pixels._op_addRenderingDef = IcePy.Operation('addRenderingDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RenderingDef, False, 0),), (), None, ())
    Pixels._op_addAllRenderingDefSet = IcePy.Operation('addAllRenderingDefSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsSettingsSeq, False, 0),), (), None, ())
    Pixels._op_removeRenderingDef = IcePy.Operation('removeRenderingDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RenderingDef, False, 0),), (), None, ())
    Pixels._op_removeAllRenderingDefSet = IcePy.Operation('removeAllRenderingDefSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsSettingsSeq, False, 0),), (), None, ())
    Pixels._op_clearSettings = IcePy.Operation('clearSettings', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Pixels._op_reloadSettings = IcePy.Operation('reloadSettings', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Pixels, False, 0),), (), None, ())
    Pixels._op_unloadThumbnails = IcePy.Operation('unloadThumbnails', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Pixels._op_sizeOfThumbnails = IcePy.Operation('sizeOfThumbnails', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Pixels._op_copyThumbnails = IcePy.Operation('copyThumbnails', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_PixelsThumbnailsSeq, False, 0), ())
    Pixels._op_addThumbnail = IcePy.Operation('addThumbnail', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Thumbnail, False, 0),), (), None, ())
    Pixels._op_addAllThumbnailSet = IcePy.Operation('addAllThumbnailSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsThumbnailsSeq, False, 0),), (), None, ())
    Pixels._op_removeThumbnail = IcePy.Operation('removeThumbnail', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Thumbnail, False, 0),), (), None, ())
    Pixels._op_removeAllThumbnailSet = IcePy.Operation('removeAllThumbnailSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_PixelsThumbnailsSeq, False, 0),), (), None, ())
    Pixels._op_clearThumbnails = IcePy.Operation('clearThumbnails', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Pixels._op_reloadThumbnails = IcePy.Operation('reloadThumbnails', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Pixels, False, 0),), (), None, ())

    _M_omero.model.Pixels = Pixels
    del Pixels

    _M_omero.model.PixelsPrx = PixelsPrx
    del PixelsPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `DoubleAnnotation.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice
import omero_model_NumericAnnotation_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'AnnotationAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_AnnotationAnnotationLink = IcePy.declareClass('::omero::model::AnnotationAnnotationLink')
    _M_omero.model._t_AnnotationAnnotationLinkPrx = IcePy.declareProxy('::omero::model::AnnotationAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'DoubleAnnotation' not in _M_omero.model.__dict__:
    _M_omero.model.DoubleAnnotation = Ice.createTempClass()
    class DoubleAnnotation(_M_omero.model.NumericAnnotation):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _ns=None, _name=None, _description=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _doubleValue=None):
            if Ice.getType(self) == _M_omero.model.DoubleAnnotation:
                raise RuntimeError('omero.model.DoubleAnnotation is an abstract class')
            _M_omero.model.NumericAnnotation.__init__(self, _id, _details, _loaded, _version, _ns, _name, _description, _annotationLinksSeq, _annotationLinksLoaded, _annotationLinksCountPerOwner)
            self._doubleValue = _doubleValue

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::Annotation', '::omero::model::BasicAnnotation', '::omero::model::DoubleAnnotation', '::omero::model::IObject', '::omero::model::NumericAnnotation')

        def ice_id(self, current=None):
            return '::omero::model::DoubleAnnotation'

        def ice_staticId():
            return '::omero::model::DoubleAnnotation'
        ice_staticId = staticmethod(ice_staticId)

        def getDoubleValue(self, current=None):
            pass

        def setDoubleValue(self, theDoubleValue, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_DoubleAnnotation)

        __repr__ = __str__

    _M_omero.model.DoubleAnnotationPrx = Ice.createTempClass()
    class DoubleAnnotationPrx(_M_omero.model.NumericAnnotationPrx):

        def getDoubleValue(self, _ctx=None):
            return _M_omero.model.DoubleAnnotation._op_getDoubleValue.invoke(self, ((), _ctx))

        def begin_getDoubleValue(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DoubleAnnotation._op_getDoubleValue.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDoubleValue(self, _r):
            return _M_omero.model.DoubleAnnotation._op_getDoubleValue.end(self, _r)

        def setDoubleValue(self, theDoubleValue, _ctx=None):
            return _M_omero.model.DoubleAnnotation._op_setDoubleValue.invoke(self, ((theDoubleValue, ), _ctx))

        def begin_setDoubleValue(self, theDoubleValue, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DoubleAnnotation._op_setDoubleValue.begin(self, ((theDoubleValue, ), _response, _ex, _sent, _ctx))

        def end_setDoubleValue(self, _r):
            return _M_omero.model.DoubleAnnotation._op_setDoubleValue.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.DoubleAnnotationPrx.ice_checkedCast(proxy, '::omero::model::DoubleAnnotation', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.DoubleAnnotationPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::DoubleAnnotation'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_DoubleAnnotationPrx = IcePy.defineProxy('::omero::model::DoubleAnnotation', DoubleAnnotationPrx)

    _M_omero.model._t_DoubleAnnotation = IcePy.declareClass('::omero::model::DoubleAnnotation')

    _M_omero.model._t_DoubleAnnotation = IcePy.defineClass('::omero::model::DoubleAnnotation', DoubleAnnotation, -1, (), True, False, _M_omero.model._t_NumericAnnotation, (), (('_doubleValue', (), _M_omero._t_RDouble, False, 0),))
    DoubleAnnotation._ice_type = _M_omero.model._t_DoubleAnnotation

    DoubleAnnotation._op_getDoubleValue = IcePy.Operation('getDoubleValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    DoubleAnnotation._op_setDoubleValue = IcePy.Operation('setDoubleValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())

    _M_omero.model.DoubleAnnotation = DoubleAnnotation
    del DoubleAnnotation

    _M_omero.model.DoubleAnnotationPrx = DoubleAnnotationPrx
    del DoubleAnnotationPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Experiment.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'ExperimentType' not in _M_omero.model.__dict__:
    _M_omero.model._t_ExperimentType = IcePy.declareClass('::omero::model::ExperimentType')
    _M_omero.model._t_ExperimentTypePrx = IcePy.declareProxy('::omero::model::ExperimentType')

if 'MicrobeamManipulation' not in _M_omero.model.__dict__:
    _M_omero.model._t_MicrobeamManipulation = IcePy.declareClass('::omero::model::MicrobeamManipulation')
    _M_omero.model._t_MicrobeamManipulationPrx = IcePy.declareProxy('::omero::model::MicrobeamManipulation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_ExperimentMicrobeamManipulationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ExperimentMicrobeamManipulationSeq = IcePy.defineSequence('::omero::model::ExperimentMicrobeamManipulationSeq', (), _M_omero.model._t_MicrobeamManipulation)

if 'Experiment' not in _M_omero.model.__dict__:
    _M_omero.model.Experiment = Ice.createTempClass()
    class Experiment(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _type=None, _microbeamManipulationSeq=None, _microbeamManipulationLoaded=False, _description=None):
            if Ice.getType(self) == _M_omero.model.Experiment:
                raise RuntimeError('omero.model.Experiment is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._type = _type
            self._microbeamManipulationSeq = _microbeamManipulationSeq
            self._microbeamManipulationLoaded = _microbeamManipulationLoaded
            self._description = _description

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::Experiment', '::omero::model::IObject')

        def ice_id(self, current=None):
            return '::omero::model::Experiment'

        def ice_staticId():
            return '::omero::model::Experiment'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getType(self, current=None):
            pass

        def setType(self, theType, current=None):
            pass

        def unloadMicrobeamManipulation(self, current=None):
            pass

        def sizeOfMicrobeamManipulation(self, current=None):
            pass

        def copyMicrobeamManipulation(self, current=None):
            pass

        def addMicrobeamManipulation(self, target, current=None):
            pass

        def addAllMicrobeamManipulationSet(self, targets, current=None):
            pass

        def removeMicrobeamManipulation(self, theTarget, current=None):
            pass

        def removeAllMicrobeamManipulationSet(self, targets, current=None):
            pass

        def clearMicrobeamManipulation(self, current=None):
            pass

        def reloadMicrobeamManipulation(self, toCopy, current=None):
            pass

        def getDescription(self, current=None):
            pass

        def setDescription(self, theDescription, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Experiment)

        __repr__ = __str__

    _M_omero.model.ExperimentPrx = Ice.createTempClass()
    class ExperimentPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Experiment._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Experiment._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Experiment._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Experiment._op_setVersion.end(self, _r)

        def getType(self, _ctx=None):
            return _M_omero.model.Experiment._op_getType.invoke(self, ((), _ctx))

        def begin_getType(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_getType.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getType(self, _r):
            return _M_omero.model.Experiment._op_getType.end(self, _r)

        def setType(self, theType, _ctx=None):
            return _M_omero.model.Experiment._op_setType.invoke(self, ((theType, ), _ctx))

        def begin_setType(self, theType, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_setType.begin(self, ((theType, ), _response, _ex, _sent, _ctx))

        def end_setType(self, _r):
            return _M_omero.model.Experiment._op_setType.end(self, _r)

        def unloadMicrobeamManipulation(self, _ctx=None):
            return _M_omero.model.Experiment._op_unloadMicrobeamManipulation.invoke(self, ((), _ctx))

        def begin_unloadMicrobeamManipulation(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_unloadMicrobeamManipulation.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadMicrobeamManipulation(self, _r):
            return _M_omero.model.Experiment._op_unloadMicrobeamManipulation.end(self, _r)

        def sizeOfMicrobeamManipulation(self, _ctx=None):
            return _M_omero.model.Experiment._op_sizeOfMicrobeamManipulation.invoke(self, ((), _ctx))

        def begin_sizeOfMicrobeamManipulation(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_sizeOfMicrobeamManipulation.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfMicrobeamManipulation(self, _r):
            return _M_omero.model.Experiment._op_sizeOfMicrobeamManipulation.end(self, _r)

        def copyMicrobeamManipulation(self, _ctx=None):
            return _M_omero.model.Experiment._op_copyMicrobeamManipulation.invoke(self, ((), _ctx))

        def begin_copyMicrobeamManipulation(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_copyMicrobeamManipulation.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyMicrobeamManipulation(self, _r):
            return _M_omero.model.Experiment._op_copyMicrobeamManipulation.end(self, _r)

        def addMicrobeamManipulation(self, target, _ctx=None):
            return _M_omero.model.Experiment._op_addMicrobeamManipulation.invoke(self, ((target, ), _ctx))

        def begin_addMicrobeamManipulation(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_addMicrobeamManipulation.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addMicrobeamManipulation(self, _r):
            return _M_omero.model.Experiment._op_addMicrobeamManipulation.end(self, _r)

        def addAllMicrobeamManipulationSet(self, targets, _ctx=None):
            return _M_omero.model.Experiment._op_addAllMicrobeamManipulationSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllMicrobeamManipulationSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_addAllMicrobeamManipulationSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllMicrobeamManipulationSet(self, _r):
            return _M_omero.model.Experiment._op_addAllMicrobeamManipulationSet.end(self, _r)

        def removeMicrobeamManipulation(self, theTarget, _ctx=None):
            return _M_omero.model.Experiment._op_removeMicrobeamManipulation.invoke(self, ((theTarget, ), _ctx))

        def begin_removeMicrobeamManipulation(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_removeMicrobeamManipulation.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeMicrobeamManipulation(self, _r):
            return _M_omero.model.Experiment._op_removeMicrobeamManipulation.end(self, _r)

        def removeAllMicrobeamManipulationSet(self, targets, _ctx=None):
            return _M_omero.model.Experiment._op_removeAllMicrobeamManipulationSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllMicrobeamManipulationSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_removeAllMicrobeamManipulationSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllMicrobeamManipulationSet(self, _r):
            return _M_omero.model.Experiment._op_removeAllMicrobeamManipulationSet.end(self, _r)

        def clearMicrobeamManipulation(self, _ctx=None):
            return _M_omero.model.Experiment._op_clearMicrobeamManipulation.invoke(self, ((), _ctx))

        def begin_clearMicrobeamManipulation(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_clearMicrobeamManipulation.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearMicrobeamManipulation(self, _r):
            return _M_omero.model.Experiment._op_clearMicrobeamManipulation.end(self, _r)

        def reloadMicrobeamManipulation(self, toCopy, _ctx=None):
            return _M_omero.model.Experiment._op_reloadMicrobeamManipulation.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadMicrobeamManipulation(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_reloadMicrobeamManipulation.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadMicrobeamManipulation(self, _r):
            return _M_omero.model.Experiment._op_reloadMicrobeamManipulation.end(self, _r)

        def getDescription(self, _ctx=None):
            return _M_omero.model.Experiment._op_getDescription.invoke(self, ((), _ctx))

        def begin_getDescription(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_getDescription.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDescription(self, _r):
            return _M_omero.model.Experiment._op_getDescription.end(self, _r)

        def setDescription(self, theDescription, _ctx=None):
            return _M_omero.model.Experiment._op_setDescription.invoke(self, ((theDescription, ), _ctx))

        def begin_setDescription(self, theDescription, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experiment._op_setDescription.begin(self, ((theDescription, ), _response, _ex, _sent, _ctx))

        def end_setDescription(self, _r):
            return _M_omero.model.Experiment._op_setDescription.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.ExperimentPrx.ice_checkedCast(proxy, '::omero::model::Experiment', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.ExperimentPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Experiment'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_ExperimentPrx = IcePy.defineProxy('::omero::model::Experiment', ExperimentPrx)

    _M_omero.model._t_Experiment = IcePy.declareClass('::omero::model::Experiment')

    _M_omero.model._t_Experiment = IcePy.defineClass('::omero::model::Experiment', Experiment, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_type', (), _M_omero.model._t_ExperimentType, False, 0),
        ('_microbeamManipulationSeq', (), _M_omero.model._t_ExperimentMicrobeamManipulationSeq, False, 0),
        ('_microbeamManipulationLoaded', (), IcePy._t_bool, False, 0),
        ('_description', (), _M_omero._t_RString, False, 0)
    ))
    Experiment._ice_type = _M_omero.model._t_Experiment

    Experiment._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Experiment._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Experiment._op_getType = IcePy.Operation('getType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ExperimentType, False, 0), ())
    Experiment._op_setType = IcePy.Operation('setType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimentType, False, 0),), (), None, ())
    Experiment._op_unloadMicrobeamManipulation = IcePy.Operation('unloadMicrobeamManipulation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Experiment._op_sizeOfMicrobeamManipulation = IcePy.Operation('sizeOfMicrobeamManipulation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Experiment._op_copyMicrobeamManipulation = IcePy.Operation('copyMicrobeamManipulation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ExperimentMicrobeamManipulationSeq, False, 0), ())
    Experiment._op_addMicrobeamManipulation = IcePy.Operation('addMicrobeamManipulation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_MicrobeamManipulation, False, 0),), (), None, ())
    Experiment._op_addAllMicrobeamManipulationSet = IcePy.Operation('addAllMicrobeamManipulationSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimentMicrobeamManipulationSeq, False, 0),), (), None, ())
    Experiment._op_removeMicrobeamManipulation = IcePy.Operation('removeMicrobeamManipulation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_MicrobeamManipulation, False, 0),), (), None, ())
    Experiment._op_removeAllMicrobeamManipulationSet = IcePy.Operation('removeAllMicrobeamManipulationSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimentMicrobeamManipulationSeq, False, 0),), (), None, ())
    Experiment._op_clearMicrobeamManipulation = IcePy.Operation('clearMicrobeamManipulation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Experiment._op_reloadMicrobeamManipulation = IcePy.Operation('reloadMicrobeamManipulation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Experiment, False, 0),), (), None, ())
    Experiment._op_getDescription = IcePy.Operation('getDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Experiment._op_setDescription = IcePy.Operation('setDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.Experiment = Experiment
    del Experiment

    _M_omero.model.ExperimentPrx = ExperimentPrx
    del ExperimentPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2009 Glencoe Software, Inc. All rights reserved.
# Use is subject to license terms supplied in LICENSE.txt
#
"""
 Version comparison functionality
"""

from __future__ import print_function
import re
import logging

# Regex copied from ome.api.IConfig.VERSION_REGEX
REGEX = re.compile(r"^.*?[-]?(\\d+[.]\\d+([.]\\d+)?)[-]?.*?$")
LOG = logging.getLogger("omero.version")


def needs_upgrade(client_version, server_version, verbose=False):
    """
    Tests whether the client version is behind the server version.
    For example::

        import omero
        from omero_version import omero_version as client_version

        client = omero.client()
        session = client.createSession()
        config = session.getConfigService()
        server_version = config.getVersion()

        upgrade = needs_upgrade(client_version, server_version)
        if upgrade:
           # Inform client

    Alternatively, from the command-line::

        ./versions.py --quiet 4.1.0 4.2.0-DEV || echo upgrade

    """
    try:
        client_cleaned = REGEX.match(client_version).group(1)
        client_split = client_cleaned.split(".")

        server_cleaned = REGEX.match(server_version).group(1)
        server_split = server_cleaned.split(".")

        rv = (client_split < server_split)
        if verbose:
            LOG.info("Client=%20s (%-5s)  v.  Server=%20s (%-5s) Upgrade? %s",
                     client_version, ".".join(client_split),
                     server_version, ".".join(server_split), rv)
        return rv

    except:
        LOG.warn("Bad versions: client=%s server=%s", client_version,
                 server_version, exc_info=1)
        return True

if __name__ == "__main__":

    import sys
    args = list(sys.argv[1:])

    if "--quiet" in args:
        args.remove("--quiet")
        logging.basicConfig(level=logging.WARN)
    else:
        logging.basicConfig(level=logging.DEBUG)

    if "--test" in args:
        print("="*10, "Test", "="*72)
        needs_upgrade("4.0", "4.1.1", True)
        needs_upgrade("4.1", "4.1.1", True)
        needs_upgrade("4.1.0", "4.1.1", True)
        needs_upgrade("4.1.0", "4.1.1-Dev", True)
        needs_upgrade("4.1.0-Dev", "4.1.1", True)
        needs_upgrade("4.1.1", "4.1.1", True)
        needs_upgrade("Beta-4.1", "4.1.1", True)
        needs_upgrade("Beta-4.1.0", "4.1.1", True)
        needs_upgrade("Beta-4.1.1", "4.1.1", True)
        needs_upgrade("4.1.1", "Beta-4.1.1", True)
        needs_upgrade("Beta-4.1.0", "Beta-4.1.1", True)
        needs_upgrade("4.1.1-Foo", "4.1.1", True)
        needs_upgrade("4.1.1-Foo", "4.1.1-Dev", True)
        needs_upgrade("4.1.1-Foo", "4.1.2-Dev", True)
        needs_upgrade("4.1.1-Foo", "4.2.0-Dev", True)
        needs_upgrade("4.1.1-Foo", "4.2", True)
        needs_upgrade("4.1.1-Foo", "5.0", True)
        needs_upgrade("v.4.1.1-Foo", "5.0", True)
        # Additions post git-describe
        needs_upgrade("v.4.1.1-Foo", "5.0", True)
        needs_upgrade("v4.1.1-Foo", "5.0", True)
        needs_upgrade("Beta-v4.1.1-Foo", "5.0", True)
        needs_upgrade("A1-4.1.1-Foo", "5.0", True)
        needs_upgrade("A1-v4.1.1-Foo", "5.0", True)
    else:
        try:
            rv = int(needs_upgrade(args[0], args[1], True))
        except:
            rv = 2
            print("""    %s [--quiet] client_version server_version
or: %s [--quiet] --test """ % (sys.argv[0], sys.argv[0]))
        sys.exit(rv)



"""
Convert the nodes and server-instances in default.xml to a multi-node
configuration

The configuration string should be in the form node1:s1,s2,... node2:s3 ...

Examples

Everything on a single node (default, the same as passing no config):
master:Blitz-0,Indexer-0,DropBox,MonitorServer,FileServer,Storm,PixelData-0,Processor-0,Tables-0,TestDropBox

Processor on a separate node:
master:Blitz-0,Indexer-0,DropBox,MonitorServer,FileServer,Storm,PixelData-0,Tables-0,TestDropBox slave:Processor-0

Two Processor and two PixelData on two separate nodes:
master:Blitz-0,Indexer-0,DropBox,MonitorServer,FileServer,Storm,Tables-0,TestDropBox slave-1:Processor-0,PixelData-0 slave-2:Processor-1,PixelData-1
"""


import re
import sys


def _getnodes(nodedescs):
    nodes = {}
    for nd in nodedescs:
        s = ''
        node, descs = nd.split(':')
        descs = descs.split(',')
        for d in descs:
            try:
                t, i = d.split('-')
            except ValueError:
                t = d
                i = None
            s += '      <server-instance template="%sTemplate"' % t
            if i is not None:
                s += ' index="%s"' % i
            if t in ('Blitz',):
                s += ' config="default"'
            if t in ('PixelData', 'Processor', 'Tables'):
                s += ' dir=""'
            s += '/>\n'
        nodes[node] = s
    return nodes


def _process_xml(xml, nodedescs):
    pattern = r'\<node name="master"\>\s*\<server-instance[^\>]*\>(.*?\</node\>)'
    m = re.search(pattern, xml, re.DOTALL)
    assert m

    master = '\n    </node>\n'
    slaves = ''
    nodes = _getnodes(nodedescs.split())
    for nodename in sorted(nodes.keys()):
        servers = nodes[nodename]
        if nodename == 'master':
            master = '%s%s' % (servers, master)
        else:
            slaves += '    <node name="%s">\n%s    </node>\n' % (nodename, servers)

    if nodes:
        xmlout = xml[:m.start(1)] + master + slaves + xml[m.end(1):]
    else:
        xmlout = xml
    return xmlout



"""
   /*
   **   Generated by blitz/resources/templates/combined.vm
   **
   **   Copyright 2007, 2008 Glencoe Software, Inc. All rights reserved.
   **   Use is subject to license terms supplied in LICENSE.txt
   **
   */
"""
try:
   unicode
except NameError:
   # Python 3: "unicode" is built-in
   unicode = str
import Ice
import IceImport
import omero
IceImport.load("omero_model_DetailsI")
IceImport.load("omero_model_LogicalChannel_ice")
from omero.rtypes import rlong
from collections import namedtuple
_omero = Ice.openModule("omero")
_omero_model = Ice.openModule("omero.model")
__name__ = "omero.model"
class LogicalChannelI(_omero_model.LogicalChannel):

      # Property Metadata
      _field_info_data = namedtuple("FieldData", ["wrapper", "nullable"])
      _field_info_type = namedtuple("FieldInfo", [
          "name",
          "pinHoleSize",
          "illumination",
          "contrastMethod",
          "excitationWave",
          "emissionWave",
          "fluor",
          "ndFilter",
          "otf",
          "detectorSettings",
          "lightSourceSettings",
          "filterSet",
          "samplesPerPixel",
          "photometricInterpretation",
          "mode",
          "pockelCellSetting",
          "channels",
          "lightPath",
          "details",
      ])
      _field_info = _field_info_type(
          name=_field_info_data(wrapper=omero.rtypes.rstring, nullable=True),
          pinHoleSize=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          illumination=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          contrastMethod=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          excitationWave=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          emissionWave=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          fluor=_field_info_data(wrapper=omero.rtypes.rstring, nullable=True),
          ndFilter=_field_info_data(wrapper=omero.rtypes.rdouble, nullable=True),
          otf=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          detectorSettings=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          lightSourceSettings=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          filterSet=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          samplesPerPixel=_field_info_data(wrapper=omero.rtypes.rint, nullable=True),
          photometricInterpretation=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          mode=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          pockelCellSetting=_field_info_data(wrapper=omero.rtypes.rint, nullable=True),
          channels=_field_info_data(wrapper=omero.proxy_to_instance, nullable=False),
          lightPath=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
          details=_field_info_data(wrapper=omero.proxy_to_instance, nullable=True),
      )  # end _field_info
      NAME =  "ome.model.core.LogicalChannel_name"
      PINHOLESIZE =  "ome.model.core.LogicalChannel_pinHoleSize"
      ILLUMINATION =  "ome.model.core.LogicalChannel_illumination"
      CONTRASTMETHOD =  "ome.model.core.LogicalChannel_contrastMethod"
      EXCITATIONWAVE =  "ome.model.core.LogicalChannel_excitationWave"
      EMISSIONWAVE =  "ome.model.core.LogicalChannel_emissionWave"
      FLUOR =  "ome.model.core.LogicalChannel_fluor"
      NDFILTER =  "ome.model.core.LogicalChannel_ndFilter"
      OTF =  "ome.model.core.LogicalChannel_otf"
      DETECTORSETTINGS =  "ome.model.core.LogicalChannel_detectorSettings"
      LIGHTSOURCESETTINGS =  "ome.model.core.LogicalChannel_lightSourceSettings"
      FILTERSET =  "ome.model.core.LogicalChannel_filterSet"
      SAMPLESPERPIXEL =  "ome.model.core.LogicalChannel_samplesPerPixel"
      PHOTOMETRICINTERPRETATION =  "ome.model.core.LogicalChannel_photometricInterpretation"
      MODE =  "ome.model.core.LogicalChannel_mode"
      POCKELCELLSETTING =  "ome.model.core.LogicalChannel_pockelCellSetting"
      CHANNELS =  "ome.model.core.LogicalChannel_channels"
      LIGHTPATH =  "ome.model.core.LogicalChannel_lightPath"
      DETAILS =  "ome.model.core.LogicalChannel_details"
      def errorIfUnloaded(self):
          if not self._loaded:
              raise _omero.UnloadedEntityException("Object unloaded:"+str(self))

      def throwNullCollectionException(self,propertyName):
          raise _omero.UnloadedEntityException(""+
          "Error updating collection:" + propertyName +"\n"+
          "Collection is currently null. This can be seen\n" +
          "by testing \""+ propertyName +"Loaded\". This implies\n"+
          "that this collection was unloaded. Please refresh this object\n"+
          "in order to update this collection.\n")

      def _toggleCollectionsLoaded(self, load):
          if load:
              self._channelsSeq = []
              self._channelsLoaded = True;
          else:
              self._channelsSeq = []
              self._channelsLoaded = False;

          pass

      def __init__(self, id=None, loaded=None):
          super(LogicalChannelI, self).__init__()
          if id is not None and isinstance(id, (str, unicode)) and ":" in id:
              parts = id.split(":")
              if len(parts) != 2:
                  raise Exception("Invalid proxy string: %s", id)
              if parts[0] != self.__class__.__name__ and \
                 parts[0]+"I" != self.__class__.__name__:
                  raise Exception("Proxy class mismatch: %s<>%s" %
                  (self.__class__.__name__, parts[0]))
              self._id = rlong(parts[1])
              if loaded is None:
                  # If no loadedness was requested with
                  # a proxy string, then assume False.
                  loaded = False
          else:
              # Relying on omero.rtypes.rlong's error-handling
              self._id = rlong(id)
              if loaded is None:
                  loaded = True  # Assume true as previously
          self._loaded = loaded
          if self._loaded:
             self._details = _omero_model.DetailsI()
             self._toggleCollectionsLoaded(True)

      def unload(self, current = None):
          self._loaded = False
          self.unloadName( )
          self.unloadPinHoleSize( )
          self.unloadIllumination( )
          self.unloadContrastMethod( )
          self.unloadExcitationWave( )
          self.unloadEmissionWave( )
          self.unloadFluor( )
          self.unloadNdFilter( )
          self.unloadOtf( )
          self.unloadDetectorSettings( )
          self.unloadLightSourceSettings( )
          self.unloadFilterSet( )
          self.unloadSamplesPerPixel( )
          self.unloadPhotometricInterpretation( )
          self.unloadMode( )
          self.unloadPockelCellSetting( )
          self.unloadChannels( )
          self.unloadLightPath( )
          self.unloadDetails( )

      def isLoaded(self, current = None):
          return self._loaded
      def unloadCollections(self, current = None):
          self._toggleCollectionsLoaded( False )
      def isGlobal(self, current = None):
          return  False ;
      def isMutable(self, current = None):
          return  True ;
      def isAnnotated(self, current = None):
          return  False ;
      def isLink(self, current = None):
          return  False ;
      def shallowCopy(self, current = None):
            if not self._loaded: return self.proxy()
            copy = LogicalChannelI()
            copy._id = self._id;
            copy._version = self._version;
            copy._details = None  # Unloading for the moment.
            raise omero.ClientError("NYI")
      def proxy(self, current = None):
          if self._id is None: raise omero.ClientError("Proxies require an id")
          return LogicalChannelI( self._id.getValue(), False )

      def getDetails(self, current = None):
          self.errorIfUnloaded()
          return self._details

      def unloadDetails(self, current = None):
          self._details = None

      def getId(self, current = None):
          return self._id

      def setId(self, _id, current = None):
          self._id = _id

      def checkUnloadedProperty(self, value, loadedField):
          if value == None:
              self.__dict__[loadedField] = False
          else:
              self.__dict__[loadedField] = True

      def getVersion(self, current = None):
          self.errorIfUnloaded()
          return self._version

      def setVersion(self, version, current = None):
          self.errorIfUnloaded()
          self._version = version

      def unloadName(self, ):
          self._nameLoaded = False
          self._name = None;

      def getName(self, current = None):
          self.errorIfUnloaded()
          return self._name

      def setName(self, _name, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.name.wrapper is not None:
              if _name is not None:
                  _name = self._field_info.name.wrapper(_name)
          self._name = _name
          pass

      def unloadPinHoleSize(self, ):
          self._pinHoleSizeLoaded = False
          self._pinHoleSize = None;

      def getPinHoleSize(self, current = None):
          self.errorIfUnloaded()
          return self._pinHoleSize

      def setPinHoleSize(self, _pinHoleSize, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.pinHoleSize.wrapper is not None:
              if _pinHoleSize is not None:
                  _pinHoleSize = self._field_info.pinHoleSize.wrapper(_pinHoleSize)
          self._pinHoleSize = _pinHoleSize
          pass

      def unloadIllumination(self, ):
          self._illuminationLoaded = False
          self._illumination = None;

      def getIllumination(self, current = None):
          self.errorIfUnloaded()
          return self._illumination

      def setIllumination(self, _illumination, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.illumination.wrapper is not None:
              if _illumination is not None:
                  _illumination = self._field_info.illumination.wrapper(_illumination)
          self._illumination = _illumination
          pass

      def unloadContrastMethod(self, ):
          self._contrastMethodLoaded = False
          self._contrastMethod = None;

      def getContrastMethod(self, current = None):
          self.errorIfUnloaded()
          return self._contrastMethod

      def setContrastMethod(self, _contrastMethod, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.contrastMethod.wrapper is not None:
              if _contrastMethod is not None:
                  _contrastMethod = self._field_info.contrastMethod.wrapper(_contrastMethod)
          self._contrastMethod = _contrastMethod
          pass

      def unloadExcitationWave(self, ):
          self._excitationWaveLoaded = False
          self._excitationWave = None;

      def getExcitationWave(self, current = None):
          self.errorIfUnloaded()
          return self._excitationWave

      def setExcitationWave(self, _excitationWave, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.excitationWave.wrapper is not None:
              if _excitationWave is not None:
                  _excitationWave = self._field_info.excitationWave.wrapper(_excitationWave)
          self._excitationWave = _excitationWave
          pass

      def unloadEmissionWave(self, ):
          self._emissionWaveLoaded = False
          self._emissionWave = None;

      def getEmissionWave(self, current = None):
          self.errorIfUnloaded()
          return self._emissionWave

      def setEmissionWave(self, _emissionWave, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.emissionWave.wrapper is not None:
              if _emissionWave is not None:
                  _emissionWave = self._field_info.emissionWave.wrapper(_emissionWave)
          self._emissionWave = _emissionWave
          pass

      def unloadFluor(self, ):
          self._fluorLoaded = False
          self._fluor = None;

      def getFluor(self, current = None):
          self.errorIfUnloaded()
          return self._fluor

      def setFluor(self, _fluor, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.fluor.wrapper is not None:
              if _fluor is not None:
                  _fluor = self._field_info.fluor.wrapper(_fluor)
          self._fluor = _fluor
          pass

      def unloadNdFilter(self, ):
          self._ndFilterLoaded = False
          self._ndFilter = None;

      def getNdFilter(self, current = None):
          self.errorIfUnloaded()
          return self._ndFilter

      def setNdFilter(self, _ndFilter, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.ndFilter.wrapper is not None:
              if _ndFilter is not None:
                  _ndFilter = self._field_info.ndFilter.wrapper(_ndFilter)
          self._ndFilter = _ndFilter
          pass

      def unloadOtf(self, ):
          self._otfLoaded = False
          self._otf = None;

      def getOtf(self, current = None):
          self.errorIfUnloaded()
          return self._otf

      def setOtf(self, _otf, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.otf.wrapper is not None:
              if _otf is not None:
                  _otf = self._field_info.otf.wrapper(_otf)
          self._otf = _otf
          pass

      def unloadDetectorSettings(self, ):
          self._detectorSettingsLoaded = False
          self._detectorSettings = None;

      def getDetectorSettings(self, current = None):
          self.errorIfUnloaded()
          return self._detectorSettings

      def setDetectorSettings(self, _detectorSettings, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.detectorSettings.wrapper is not None:
              if _detectorSettings is not None:
                  _detectorSettings = self._field_info.detectorSettings.wrapper(_detectorSettings)
          self._detectorSettings = _detectorSettings
          pass

      def unloadLightSourceSettings(self, ):
          self._lightSourceSettingsLoaded = False
          self._lightSourceSettings = None;

      def getLightSourceSettings(self, current = None):
          self.errorIfUnloaded()
          return self._lightSourceSettings

      def setLightSourceSettings(self, _lightSourceSettings, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.lightSourceSettings.wrapper is not None:
              if _lightSourceSettings is not None:
                  _lightSourceSettings = self._field_info.lightSourceSettings.wrapper(_lightSourceSettings)
          self._lightSourceSettings = _lightSourceSettings
          pass

      def unloadFilterSet(self, ):
          self._filterSetLoaded = False
          self._filterSet = None;

      def getFilterSet(self, current = None):
          self.errorIfUnloaded()
          return self._filterSet

      def setFilterSet(self, _filterSet, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.filterSet.wrapper is not None:
              if _filterSet is not None:
                  _filterSet = self._field_info.filterSet.wrapper(_filterSet)
          self._filterSet = _filterSet
          pass

      def unloadSamplesPerPixel(self, ):
          self._samplesPerPixelLoaded = False
          self._samplesPerPixel = None;

      def getSamplesPerPixel(self, current = None):
          self.errorIfUnloaded()
          return self._samplesPerPixel

      def setSamplesPerPixel(self, _samplesPerPixel, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.samplesPerPixel.wrapper is not None:
              if _samplesPerPixel is not None:
                  _samplesPerPixel = self._field_info.samplesPerPixel.wrapper(_samplesPerPixel)
          self._samplesPerPixel = _samplesPerPixel
          pass

      def unloadPhotometricInterpretation(self, ):
          self._photometricInterpretationLoaded = False
          self._photometricInterpretation = None;

      def getPhotometricInterpretation(self, current = None):
          self.errorIfUnloaded()
          return self._photometricInterpretation

      def setPhotometricInterpretation(self, _photometricInterpretation, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.photometricInterpretation.wrapper is not None:
              if _photometricInterpretation is not None:
                  _photometricInterpretation = self._field_info.photometricInterpretation.wrapper(_photometricInterpretation)
          self._photometricInterpretation = _photometricInterpretation
          pass

      def unloadMode(self, ):
          self._modeLoaded = False
          self._mode = None;

      def getMode(self, current = None):
          self.errorIfUnloaded()
          return self._mode

      def setMode(self, _mode, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.mode.wrapper is not None:
              if _mode is not None:
                  _mode = self._field_info.mode.wrapper(_mode)
          self._mode = _mode
          pass

      def unloadPockelCellSetting(self, ):
          self._pockelCellSettingLoaded = False
          self._pockelCellSetting = None;

      def getPockelCellSetting(self, current = None):
          self.errorIfUnloaded()
          return self._pockelCellSetting

      def setPockelCellSetting(self, _pockelCellSetting, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.pockelCellSetting.wrapper is not None:
              if _pockelCellSetting is not None:
                  _pockelCellSetting = self._field_info.pockelCellSetting.wrapper(_pockelCellSetting)
          self._pockelCellSetting = _pockelCellSetting
          pass

      def unloadChannels(self, current = None):
          self._channelsLoaded = False
          self._channelsSeq = None;

      def _getChannels(self, current = None):
          self.errorIfUnloaded()
          return self._channelsSeq

      def _setChannels(self, _channels, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.channelsSeq.wrapper is not None:
              if _channels is not None:
                  _channels = self._field_info.channelsSeq.wrapper(_channels)
          self._channelsSeq = _channels
          self.checkUnloadedProperty(_channels,'channelsLoaded')

      def isChannelsLoaded(self):
          return self._channelsLoaded

      def sizeOfChannels(self, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: return -1
          return len(self._channelsSeq)

      def copyChannels(self, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          return list(self._channelsSeq)

      def iterateChannels(self):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          return iter(self._channelsSeq)

      def addChannel(self, target, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          self._channelsSeq.append( target );
          target.setLogicalChannel( self )

      def addAllChannelSet(self, targets, current = None):
          self.errorIfUnloaded()
          if  not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          self._channelsSeq.extend( targets )
          for target in targets:
              target.setLogicalChannel( self )

      def removeChannel(self, target, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          self._channelsSeq.remove( target )
          target.setLogicalChannel( None )

      def removeAllChannelSet(self, targets, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          for elt in targets:
              elt.setLogicalChannel( None )
              self._channelsSeq.remove( elt )

      def clearChannels(self, current = None):
          self.errorIfUnloaded()
          if not self._channelsLoaded: self.throwNullCollectionException("channelsSeq")
          for elt in self._channelsSeq:
              elt.setLogicalChannel( None )
          self._channelsSeq = list()

      def reloadChannels(self, toCopy, current = None):
          self.errorIfUnloaded()
          if self._channelsLoaded:
              raise omero.ClientError("Cannot reload active collection: channelsSeq")
          if not toCopy:
              raise omero.ClientError("Argument cannot be null")
          if toCopy.getId().getValue() != self.getId().getValue():
             raise omero.ClientError("Argument must have the same id as this instance")
          if toCopy.getDetails().getUpdateEvent().getId().getValue() < self.getDetails().getUpdateEvent().getId().getValue():
             raise omero.ClientError("Argument may not be older than this instance")
          copy = toCopy.copyChannels() # May also throw
          for elt in copy:
              elt.setLogicalChannel( self )
          self._channelsSeq = copy
          toCopy.unloadChannels()
          self._channelsLoaded = True

      def unloadLightPath(self, ):
          self._lightPathLoaded = False
          self._lightPath = None;

      def getLightPath(self, current = None):
          self.errorIfUnloaded()
          return self._lightPath

      def setLightPath(self, _lightPath, current = None, wrap=False):
          self.errorIfUnloaded()
          if wrap and self._field_info.lightPath.wrapper is not None:
              if _lightPath is not None:
                  _lightPath = self._field_info.lightPath.wrapper(_lightPath)
          self._lightPath = _lightPath
          pass


      def ice_postUnmarshal(self):
          """
          Provides additional initialization once all data loaded
          """
          pass # Currently unused


      def ice_preMarshal(self):
          """
          Provides additional validation before data is sent
          """
          pass # Currently unused

      def __getattr__(self, name):
          """
          Reroutes all access to object.field through object.getField() or object.isField()
          """
          if "_" in name:  # Ice disallows underscores, so these should be treated normally.
              return object.__getattribute__(self, name)
          field  = "_" + name
          capitalized = name[0].capitalize() + name[1:]
          getter = "get" + capitalized
          questn = "is" + capitalized
          try:
              self.__dict__[field]
              if hasattr(self, getter):
                  method = getattr(self, getter)
                  return method()
              elif hasattr(self, questn):
                  method = getattr(self, questn)
                  return method()
          except:
              pass
          raise AttributeError("'%s' object has no attribute '%s' or '%s'" % (self.__class__.__name__, getter, questn))

      def __setattr__(self, name, value):
          """
          Reroutes all access to object.field through object.getField(), with the caveat
          that all sets on variables starting with "_" are permitted directly.
          """
          if name.startswith("_"):
              self.__dict__[name] = value
              return
          else:
              field  = "_" + name
              setter = "set" + name[0].capitalize() + name[1:]
              if hasattr(self, field) and hasattr(self, setter):
                  method = getattr(self, setter)
                  return method(value)
          raise AttributeError("'%s' object has no attribute '%s'" % (self.__class__.__name__, setter))

_omero_model.LogicalChannelI = LogicalChannelI
